import { TransformCase } from '../config/IConfig';
import { ITableMetadata } from './Dialect';
export declare type CaseTransformer = (s: string) => string;
export declare const toUpperCase: (s: string) => string;
export declare const toLowerCase: (s: string) => string;
/**
 * Check if provided string is ASCII
 * @param {string} s
 * @returns {boolean}
 */
export declare const isASCII: (s: string) => boolean;
/**
 * Wrapper for case transformer. Returns unprocessed string for non ASCII characters
 * @param {CaseTransformer} transformer
 * @returns {CaseTransformer}
 */
export declare const transformerFactory: (transformer: CaseTransformer) => CaseTransformer;
/**
 * Return transformer for the provided case
 * @param  {TransformCase} transformCase
 * @returns {function(s: string): string}
 */
export declare const getTransformer: (transformCase: TransformCase) => (s: string) => string;
/**
 * Transform ITableMetadata object using the provided case
 * @param {ITableMetadata} tableMetadata
 * @param {TransformCase} transformCase
 * @returns {ITableMetadata}
 */
export declare const caseTransformer: (tableMetadata: ITableMetadata, transformCase: TransformCase) => ITableMetadata;
/**
 * Unknown mapping warning
 * @param {string} dataType
 * @returns {string}
 */
export declare const warnUnknownMappingForDataType: (dataType: string) => void;
/**
 * Generates precision signature
 * @param {Array<string|number>} args
 * @returns {string} (80) or (10,4) or ...
 */
export declare const generatePrecisionSignature: (...args: (string | number | null | undefined)[]) => string;
